# aptos_api_dart
The Aptos Node API is a RESTful API for client applications to interact with the Aptos blockchain.

This Dart package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 1.0.1
- Build package: org.openapitools.codegen.languages.DartDioClientCodegen
For more information, please visit [https://github.com/aptos-labs/aptos-core](https://github.com/aptos-labs/aptos-core)

## Requirements

* Dart 2.12.0 or later OR Flutter 1.26.0 or later
* Dio 4.0.0+

## Installation & Usage

### pub.dev
To use the package from [pub.dev](https://pub.dev), please include the following in pubspec.yaml
```yaml
dependencies:
  aptos_api_dart: 0.0.1
```

### Github
If this Dart package is published to Github, please include the following in pubspec.yaml
```yaml
dependencies:
  aptos_api_dart:
    git:
      url: https://github.com/GIT_USER_ID/GIT_REPO_ID.git
      #ref: main
```

### Local development
To use the package from your local drive, please include the following in pubspec.yaml
```yaml
dependencies:
  aptos_api_dart:
    path: /path/to/aptos_api_dart
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```dart
import 'package:aptos_api_dart/aptos_api_dart.dart';


final api = AptosApiDart().getAccountsApi();
final String address = address_example; // String | 
final String ledgerVersion = ledgerVersion_example; // String | 

try {
    final response = await api.getAccount(address, ledgerVersion);
    print(response);
} catch on DioError (e) {
    print("Exception when calling AccountsApi->getAccount: $e\n");
}

```

## Documentation for API Endpoints

All URIs are relative to *https://raw.githubusercontent.com/v1*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
[*AccountsApi*](doc/AccountsApi.md) | [**getAccount**](doc/AccountsApi.md#getaccount) | **GET** /accounts/{address} | Get account
[*AccountsApi*](doc/AccountsApi.md) | [**getAccountModule**](doc/AccountsApi.md#getaccountmodule) | **GET** /accounts/{address}/module/{module_name} | Get specific account module
[*AccountsApi*](doc/AccountsApi.md) | [**getAccountModules**](doc/AccountsApi.md#getaccountmodules) | **GET** /accounts/{address}/modules | Get account modules
[*AccountsApi*](doc/AccountsApi.md) | [**getAccountResource**](doc/AccountsApi.md#getaccountresource) | **GET** /accounts/{address}/resource/{resource_type} | Get specific account resource
[*AccountsApi*](doc/AccountsApi.md) | [**getAccountResources**](doc/AccountsApi.md#getaccountresources) | **GET** /accounts/{address}/resources | Get account resources
[*BlocksApi*](doc/BlocksApi.md) | [**getBlockByHeight**](doc/BlocksApi.md#getblockbyheight) | **GET** /blocks/by_height/{block_height} | Get blocks by height
[*BlocksApi*](doc/BlocksApi.md) | [**getBlockByVersion**](doc/BlocksApi.md#getblockbyversion) | **GET** /blocks/by_version/{version} | Get blocks by version
[*EventsApi*](doc/EventsApi.md) | [**getEventsByEventHandle**](doc/EventsApi.md#geteventsbyeventhandle) | **GET** /accounts/{address}/events/{event_handle}/{field_name} | Get events by event handle
[*EventsApi*](doc/EventsApi.md) | [**getEventsByEventKey**](doc/EventsApi.md#geteventsbyeventkey) | **GET** /events/{event_key} | Get events by event key
[*GeneralApi*](doc/GeneralApi.md) | [**getLedgerInfo**](doc/GeneralApi.md#getledgerinfo) | **GET** / | Get ledger info
[*GeneralApi*](doc/GeneralApi.md) | [**healthy**](doc/GeneralApi.md#healthy) | **GET** /-/healthy | Check basic node health
[*GeneralApi*](doc/GeneralApi.md) | [**spec**](doc/GeneralApi.md#spec) | **GET** /spec | Show OpenAPI explorer
[*TablesApi*](doc/TablesApi.md) | [**getTableItem**](doc/TablesApi.md#gettableitem) | **POST** /tables/{table_handle}/item | Get table item
[*TransactionsApi*](doc/TransactionsApi.md) | [**encodeSubmission**](doc/TransactionsApi.md#encodesubmission) | **POST** /transactions/encode_submission | Encode submission
[*TransactionsApi*](doc/TransactionsApi.md) | [**estimateGasPrice**](doc/TransactionsApi.md#estimategasprice) | **GET** /estimate_gas_price | Estimate gas price
[*TransactionsApi*](doc/TransactionsApi.md) | [**getAccountTransactions**](doc/TransactionsApi.md#getaccounttransactions) | **GET** /accounts/{address}/transactions | Get account transactions
[*TransactionsApi*](doc/TransactionsApi.md) | [**getTransactionByHash**](doc/TransactionsApi.md#gettransactionbyhash) | **GET** /transactions/by_hash/{txn_hash} | Get transaction by hash
[*TransactionsApi*](doc/TransactionsApi.md) | [**getTransactionByVersion**](doc/TransactionsApi.md#gettransactionbyversion) | **GET** /transactions/by_version/{txn_version} | Get transaction by version
[*TransactionsApi*](doc/TransactionsApi.md) | [**getTransactions**](doc/TransactionsApi.md#gettransactions) | **GET** /transactions | Get transactions
[*TransactionsApi*](doc/TransactionsApi.md) | [**simulateTransaction**](doc/TransactionsApi.md#simulatetransaction) | **POST** /transactions/simulate | Simulate transaction
[*TransactionsApi*](doc/TransactionsApi.md) | [**submitBatchTransactions**](doc/TransactionsApi.md#submitbatchtransactions) | **POST** /transactions/batch | 
[*TransactionsApi*](doc/TransactionsApi.md) | [**submitTransaction**](doc/TransactionsApi.md#submittransaction) | **POST** /transactions | Submit transaction


## Documentation For Models

 - [AccountData](doc/AccountData.md)
 - [AccountSignature](doc/AccountSignature.md)
 - [AccountSignatureEd25519Signature](doc/AccountSignatureEd25519Signature.md)
 - [AccountSignatureEd25519SignatureAllOf](doc/AccountSignatureEd25519SignatureAllOf.md)
 - [AccountSignatureMultiEd25519Signature](doc/AccountSignatureMultiEd25519Signature.md)
 - [AccountSignatureMultiEd25519SignatureAllOf](doc/AccountSignatureMultiEd25519SignatureAllOf.md)
 - [AptosError](doc/AptosError.md)
 - [AptosErrorCode](doc/AptosErrorCode.md)
 - [Block](doc/Block.md)
 - [BlockMetadataTransaction](doc/BlockMetadataTransaction.md)
 - [DecodedTableData](doc/DecodedTableData.md)
 - [DeleteModule](doc/DeleteModule.md)
 - [DeleteResource](doc/DeleteResource.md)
 - [DeleteTableItem](doc/DeleteTableItem.md)
 - [DeletedTableData](doc/DeletedTableData.md)
 - [DirectWriteSet](doc/DirectWriteSet.md)
 - [Ed25519Signature](doc/Ed25519Signature.md)
 - [EncodeSubmissionRequest](doc/EncodeSubmissionRequest.md)
 - [EntryFunctionPayload](doc/EntryFunctionPayload.md)
 - [Event](doc/Event.md)
 - [GasEstimation](doc/GasEstimation.md)
 - [GenesisPayload](doc/GenesisPayload.md)
 - [GenesisPayloadWriteSetPayload](doc/GenesisPayloadWriteSetPayload.md)
 - [GenesisPayloadWriteSetPayloadAllOf](doc/GenesisPayloadWriteSetPayloadAllOf.md)
 - [GenesisTransaction](doc/GenesisTransaction.md)
 - [HealthCheckSuccess](doc/HealthCheckSuccess.md)
 - [IndexResponse](doc/IndexResponse.md)
 - [ModuleBundlePayload](doc/ModuleBundlePayload.md)
 - [MoveFunction](doc/MoveFunction.md)
 - [MoveFunctionGenericTypeParam](doc/MoveFunctionGenericTypeParam.md)
 - [MoveFunctionVisibility](doc/MoveFunctionVisibility.md)
 - [MoveModule](doc/MoveModule.md)
 - [MoveModuleBytecode](doc/MoveModuleBytecode.md)
 - [MoveResource](doc/MoveResource.md)
 - [MoveScriptBytecode](doc/MoveScriptBytecode.md)
 - [MoveStruct](doc/MoveStruct.md)
 - [MoveStructField](doc/MoveStructField.md)
 - [MoveStructGenericTypeParam](doc/MoveStructGenericTypeParam.md)
 - [MoveValue](doc/MoveValue.md)
 - [MultiAgentSignature](doc/MultiAgentSignature.md)
 - [MultiEd25519Signature](doc/MultiEd25519Signature.md)
 - [PendingTransaction](doc/PendingTransaction.md)
 - [RoleType](doc/RoleType.md)
 - [ScriptPayload](doc/ScriptPayload.md)
 - [ScriptWriteSet](doc/ScriptWriteSet.md)
 - [StateCheckpointTransaction](doc/StateCheckpointTransaction.md)
 - [SubmitTransactionRequest](doc/SubmitTransactionRequest.md)
 - [TableItemRequest](doc/TableItemRequest.md)
 - [Transaction](doc/Transaction.md)
 - [TransactionBlockMetadataTransaction](doc/TransactionBlockMetadataTransaction.md)
 - [TransactionBlockMetadataTransactionAllOf](doc/TransactionBlockMetadataTransactionAllOf.md)
 - [TransactionGenesisTransaction](doc/TransactionGenesisTransaction.md)
 - [TransactionGenesisTransactionAllOf](doc/TransactionGenesisTransactionAllOf.md)
 - [TransactionPayload](doc/TransactionPayload.md)
 - [TransactionPayloadEntryFunctionPayload](doc/TransactionPayloadEntryFunctionPayload.md)
 - [TransactionPayloadEntryFunctionPayloadAllOf](doc/TransactionPayloadEntryFunctionPayloadAllOf.md)
 - [TransactionPayloadModuleBundlePayload](doc/TransactionPayloadModuleBundlePayload.md)
 - [TransactionPayloadModuleBundlePayloadAllOf](doc/TransactionPayloadModuleBundlePayloadAllOf.md)
 - [TransactionPayloadScriptPayload](doc/TransactionPayloadScriptPayload.md)
 - [TransactionPayloadScriptPayloadAllOf](doc/TransactionPayloadScriptPayloadAllOf.md)
 - [TransactionPendingTransaction](doc/TransactionPendingTransaction.md)
 - [TransactionPendingTransactionAllOf](doc/TransactionPendingTransactionAllOf.md)
 - [TransactionSignature](doc/TransactionSignature.md)
 - [TransactionSignatureEd25519Signature](doc/TransactionSignatureEd25519Signature.md)
 - [TransactionSignatureMultiAgentSignature](doc/TransactionSignatureMultiAgentSignature.md)
 - [TransactionSignatureMultiAgentSignatureAllOf](doc/TransactionSignatureMultiAgentSignatureAllOf.md)
 - [TransactionSignatureMultiEd25519Signature](doc/TransactionSignatureMultiEd25519Signature.md)
 - [TransactionStateCheckpointTransaction](doc/TransactionStateCheckpointTransaction.md)
 - [TransactionStateCheckpointTransactionAllOf](doc/TransactionStateCheckpointTransactionAllOf.md)
 - [TransactionUserTransaction](doc/TransactionUserTransaction.md)
 - [TransactionUserTransactionAllOf](doc/TransactionUserTransactionAllOf.md)
 - [TransactionsBatchSingleSubmissionFailure](doc/TransactionsBatchSingleSubmissionFailure.md)
 - [TransactionsBatchSubmissionResult](doc/TransactionsBatchSubmissionResult.md)
 - [UserTransaction](doc/UserTransaction.md)
 - [VersionedEvent](doc/VersionedEvent.md)
 - [WriteModule](doc/WriteModule.md)
 - [WriteResource](doc/WriteResource.md)
 - [WriteSet](doc/WriteSet.md)
 - [WriteSetChange](doc/WriteSetChange.md)
 - [WriteSetChangeDeleteModule](doc/WriteSetChangeDeleteModule.md)
 - [WriteSetChangeDeleteModuleAllOf](doc/WriteSetChangeDeleteModuleAllOf.md)
 - [WriteSetChangeDeleteResource](doc/WriteSetChangeDeleteResource.md)
 - [WriteSetChangeDeleteResourceAllOf](doc/WriteSetChangeDeleteResourceAllOf.md)
 - [WriteSetChangeDeleteTableItem](doc/WriteSetChangeDeleteTableItem.md)
 - [WriteSetChangeDeleteTableItemAllOf](doc/WriteSetChangeDeleteTableItemAllOf.md)
 - [WriteSetChangeWriteModule](doc/WriteSetChangeWriteModule.md)
 - [WriteSetChangeWriteModuleAllOf](doc/WriteSetChangeWriteModuleAllOf.md)
 - [WriteSetChangeWriteResource](doc/WriteSetChangeWriteResource.md)
 - [WriteSetChangeWriteResourceAllOf](doc/WriteSetChangeWriteResourceAllOf.md)
 - [WriteSetChangeWriteTableItem](doc/WriteSetChangeWriteTableItem.md)
 - [WriteSetChangeWriteTableItemAllOf](doc/WriteSetChangeWriteTableItemAllOf.md)
 - [WriteSetDirectWriteSet](doc/WriteSetDirectWriteSet.md)
 - [WriteSetDirectWriteSetAllOf](doc/WriteSetDirectWriteSetAllOf.md)
 - [WriteSetPayload](doc/WriteSetPayload.md)
 - [WriteSetScriptWriteSet](doc/WriteSetScriptWriteSet.md)
 - [WriteSetScriptWriteSetAllOf](doc/WriteSetScriptWriteSetAllOf.md)
 - [WriteTableItem](doc/WriteTableItem.md)


## Documentation For Authorization

 All endpoints do not require authorization.


## Author



